Sophie

Sophie

distrib > Mandriva > 2009.0 > x86_64 > by-pkgid > 1d7b43c0ed741deb979c34b282dd63aa > files > 1

liblockfile-1.06.1-1mdv2007.0.src.rpm

--- liblockfile-1.06.1/lockfile.c.eaccess	2004-06-04 17:14:21.000000000 +0200
+++ liblockfile-1.06.1/lockfile.c	2006-08-09 11:59:03.000000000 +0200
@@ -54,7 +54,7 @@
 #ifdef LIB
 static
 #endif
-int eaccess(char *fn, gid_t gid, struct stat *st)
+int lockfile_eaccess(char *fn, gid_t gid, struct stat *st)
 {
 	struct stat	tmp;
 	uid_t		uid = geteuid();
@@ -96,7 +96,7 @@
 		*p = 0;
 	else
 		strcpy(dir, ".");
-	if (eaccess(dir, egid, NULL) >= 0) {
+	if (lockfile_eaccess(dir, egid, NULL) >= 0) {
 		free(dir);
 		return 0;
 	}
@@ -111,7 +111,7 @@
 			return 0;
 		mailgid = st.st_gid;
 	}
-	ret = eaccess(dir, mailgid, NULL) >= 0;
+	ret = lockfile_eaccess(dir, mailgid, NULL) >= 0;
 	free (dir);
 	return ret;
 }
--- liblockfile-1.06.1/dotlockfile.c.eaccess	2003-05-15 14:08:28.000000000 +0200
+++ liblockfile-1.06.1/dotlockfile.c	2006-08-09 11:57:56.000000000 +0200
@@ -42,7 +42,7 @@
 extern int optind;
 #endif
 
-extern int eaccess(char *, gid_t, struct stat *);
+extern int lockfile_eaccess(char *, gid_t, struct stat *);
 
 /*
  *	Sleep for an amout of time while regulary checking if
@@ -252,14 +252,14 @@
 		return L_ERROR;
 	}
 	gid = getgid();
-	if (eaccess(dir, gid, &st) < 0) {
+	if (lockfile_eaccess(dir, gid, &st) < 0) {
 		if (errno == ENOENT) {
 enoent:
 			if (!quiet) fprintf(stderr,
 				"dotlockfile: %s: no such directory\n", dir);
 			return L_TMPLOCK;
 		}
-		if ((r = eaccess(dir, getegid(), &st) < 0) && errno == ENOENT)
+		if ((r = lockfile_eaccess(dir, getegid(), &st) < 0) && errno == ENOENT)
 			goto enoent;
 		if (r < 0 || !ismaillock(lockfile, pwd->pw_name)) {
 			if (!quiet) fprintf(stderr,
@@ -272,7 +272,7 @@
 	/*
 	 *	Now we should be able to chdir() to the lock directory.
 	 *	When we stat("."), it should be the same as at the
 	 *	eaccess() check or someone played symlink() games on us.
 	 */
 	if (chdir(dir) < 0 || stat(".", &st2) < 0) {
 		if (!quiet) fprintf(stderr,
@@ -272,7 +272,7 @@
 	 *	Now we should be able to chdir() to the lock directory.
 	 *	When we stat("."), it should be the same as at the
-	 *	eaccess() check or someone played symlink() games on us.
+	 *	lockfile_eaccess() check or someone played symlink() games on us.
 	 */
 	if (chdir(dir) < 0 || stat(".", &st2) < 0) {